@@ -16,7 +16,6 @@ from .shared import (
     import_user_data,
 )
 from .cfn import *
-from .iam import IAMInstanceProfile
 
 try:
     from cfnExt import *
@@ -599,8 +598,7 @@ def AS_ScalingPolicies(key):
 
     if Out_String:
         # Outputs
-        O_Policy = Output(key)
-        O_Policy.Value = Sub(",".join(Out_String), **Out_Map)
+        O_Policy = Output(key, Value=Sub(",".join(Out_String), **Out_Map))
 
         add_obj(O_Policy)
 
@@ -621,15 +619,17 @@ def AS_LaunchTemplate():
 
         UserDataApp.extend(["#${%s}\n" % envname])
 
-        p_EnvAppVersion = Parameter(envname)
-        p_EnvAppVersion.Description = f"Application {n} version"
-        p_EnvAppVersion.AllowedPattern = "^[a-zA-Z0-9-_.]*$"
+        p_EnvAppVersion = Parameter(
+            envname,
+            Description=f"Application {n} version",
+            AllowedPattern="^[a-zA-Z0-9-_.]*$",
+        )
 
-        p_AppsRepoName = Parameter(reponame)
-        p_AppsRepoName.Description = (
-            f"App {n} Repo Name - empty for default based on env/role"
+        p_AppsRepoName = Parameter(
+            reponame,
+            Description=f"App {n} Repo Name - empty for default based on env/role",
+            AllowedPattern="^[a-zA-Z0-9-_.]*$",
         )
-        p_AppsRepoName.AllowedPattern = "^[a-zA-Z0-9-_.]*$"
 
         # parameters
         add_obj(
@@ -680,13 +680,10 @@ def AS_LaunchTemplate():
         Tags_List.append(asg.Tag(envname, Ref(envname), True))
 
         # outputs
-        Output_app = Output(envname)
-        Output_app.Value = Ref(envname)
-        add_obj(Output_app)
+        Output_app = Output(envname, Value=Ref(envname))
+        Output_repo = Output(reponame, Value=get_endvalue(reponame))
 
-        Output_repo = Output(reponame)
-        Output_repo.Value = get_endvalue(reponame)
-        add_obj(Output_repo)
+        add_obj([Output_app, Output_repo])
 
     InitConfigSetup = ASInitConfigSetup()
     InitConfigSetup.ibox_env_app = IBoxEnvApp
@@ -737,8 +734,6 @@ def AS_LaunchTemplate():
         SecurityGroups
     )
 
-    R_InstanceProfile = IAMInstanceProfile("InstanceProfile")
-
     # Import role specific cfn definition
     try:
         # Do not use role but direct cfg yaml configuration (ecs + cluster)
@@ -774,7 +769,7 @@ def AS_LaunchTemplate():
             ),
         )
 
-    add_obj([R_LaunchTemplate, R_InstanceProfile])
+    add_obj(R_LaunchTemplate)
 
     Tags = asg.Tags()
     Tags.tags = Tags_List
@@ -798,9 +793,11 @@ def AS_Autoscaling(key):
     # Resources
     LaunchTemplateTags = AS_LaunchTemplate()
 
-    R_ASG = asg.AutoScalingGroup("AutoScalingGroupBase")
-    R_ASG.LoadBalancerNames = LoadBalancers
-    R_ASG.TargetGroupARNs = TargetGroups
+    R_ASG = asg.AutoScalingGroup(
+        "AutoScalingGroupBase",
+        LoadBalancerNames=LoadBalancers,
+        TargetGroupARNs=TargetGroups,
+    )
 
     auto_get_props(R_ASG)
 
