@@ -316,6 +316,7 @@ CFG_TO_FUNC = {
     "CloudFrontOriginAccessIdentity": {
         "module": "joker",
         "func": ("cloudfront", "CloudFrontOriginAccessIdentity"),
+        "dep": ["Bucket"],
     },
     "CloudFrontOriginRequestPolicy": {
         "module": "joker",
@@ -339,6 +340,7 @@ CFG_TO_FUNC = {
         "module": "joker",
         "func": ("ec2", "VPCPeeringConnection"),
     },
+    "ECRRepository": {"module": "ecr", "func": "ECR_Repositories"},
     "ECSCapacityProvider": {"module": "joker", "func": ("ecs", "CapacityProvider")},
     "ECSCluster": {"module": "joker", "func": ("ecs", "Cluster")},
     "ECSClusterCapacityProviderAssociations": {
@@ -363,7 +365,7 @@ CFG_TO_FUNC = {
     "IAMGroup": {"module": "iam", "func": "IAM_Groups"},
     "IAMInstanceProfile": {"module": "joker", "func": ("iam", "InstanceProfile")},
     "IAMManagedPolicy": {"module": "joker", "func": ("iam", "ManagedPolicy")},
-    "IAMPolicy": {"module": "joker", "func": ("iam", "PolicyType")},
+    "IAMPolicy": {"module": "joker", "func": ("iam", "PolicyType"), "dep": ["Bucket"]},
     "IAMRole": {
         "module": "joker",
         "func": ("iam", "Role"),
@@ -410,7 +412,6 @@ CFG_TO_FUNC = {
     },
     "RDSDBInstance": {"module": "rds", "func": "RDS_DB"},
     "RDSDBSubnetGroup": {"module": "joker", "func": ("rds", "DBSubnetGroup")},
-    "Repository": {"module": "ecr", "func": "ECR_Repositories"},
     "Route53HostedZone": {"module": "joker", "func": ("route53", "HostedZone")},
     "Route53RecordSet": {
         "module": "joker",
