@@ -11,6 +11,7 @@ IBOX_SPECIAL_KEYS = (
     "IBOX_REMAPNAME",
     "IBOX_INDEXNAME",
     "IBOX_PROPNAME",
+    "IBOX_CURNAME",
     "IBOX_LINKED_OBJ_NAME",
     "IBOX_LINKED_OBJ_INDEX",
     "IBOX_LINKED_OBJ_FOR",
@@ -320,16 +321,41 @@ def get_resvalue(resname, propname):
     return getattr(res, propname)
 
 
+def iboxif(if_wrapper, mapname, value):
+    condname = if_wrapper[0].replace("IBOX_MAPNAME", mapname)
+    condname = parse_ibox_key(condname)
+    condvalues = []
+    for i in if_wrapper[1:3]:
+        if isinstance(i, str) and i.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
+            v = eval(i)
+        else:
+            v = i
+        condvalues.append(v)
+
+    if condvalues[0] == "IBOX_IFVALUE":
+        value = If(condname, value, condvalues[1])
+    else:
+        value = If(condname, condvalues[0], value)
+
+    return value
+
+
 def get_dictvalue(key):
     if isinstance(key, list):
         value = [get_dictvalue(k) for k in key]
     elif isinstance(key, dict) and "IBOX_LIST" in key:
         # Usefull for KMS policy and other generic dict properties
         value = []
-        for i, k in key.items():
+        for i, k in copy.deepcopy(key).items():
             if i == "IBOX_LIST":
                 continue
-            value.append({j: get_dictvalue(w) for j, w in k.items()})
+            # parse IBOX_IF
+            if_wrapper = k.pop("IBOX_IF", [])
+            prop_obj = {j: get_dictvalue(w) for j, w in k.items()}
+            if if_wrapper:
+                value.append(iboxif(if_wrapper, "", prop_obj))
+            else:
+                value.append(prop_obj)
     elif isinstance(key, dict):
         value = {i: get_dictvalue(k) for i, k in key.items()}
     elif isinstance(key, str):
@@ -554,24 +580,6 @@ def auto_get_props(
     # IBOX_OUTPUT
     IBOX_PROPS = {"MAP": {}}
 
-    def _iboxif(if_wrapper, mapname, value):
-        condname = if_wrapper[0].replace("IBOX_MAPNAME", mapname)
-        condname = parse_ibox_key(condname)
-        condvalues = []
-        for i in if_wrapper[1:3]:
-            if isinstance(i, str) and i.startswith(cfg.EVAL_FUNCTIONS_IN_CFG):
-                v = eval(i)
-            else:
-                v = i
-            condvalues.append(v)
-
-        if condvalues[0] == "IBOX_IFVALUE":
-            value = If(condname, value, condvalues[1])
-        else:
-            value = If(condname, condvalues[0], value)
-
-        return value
-
     def _get_obj(obj, key, obj_propname, mapname):
         props = obj.props
         mapname_obj = f"{mapname}{obj_propname}"
@@ -593,7 +601,7 @@ def auto_get_props(
                     pass
                 else:
                     del v["IBOX_IF"]
-                    v = _iboxif(if_wrapper, mapname, v)
+                    v = iboxif(if_wrapper, mapname, v)
 
                 prop_list.append(v)
 
@@ -619,10 +627,19 @@ def auto_get_props(
 
             if prop_class.__bases__[0].__name__ in ["AWSProperty", "AWSAttribute"]:
                 _populate(prop_obj, key=key[obj_propname], mapname=mapname_obj)
+                # Check for incomplete AWSProperty object and set obj to None to skip it
+                try:
+                    prop_obj.to_dict()
+                except Exception as e:
+                    # logging.warning(f"Resource with missing properties: {obj_propname}\n\t\t{e}")
+                    prop_obj = None
             elif prop_class.__name__ == "dict":
                 prop_obj = get_dictvalue(key[obj_propname])
             elif prop_class.__name__ == "Tags":
                 prop_obj = _get_obj_tags()
+            elif prop_class.__name__ == "str" and obj_propname == "LifecyclePolicyText":
+                # str but can be represented as dict Ex. ECR LifecyclePolicyText
+                prop_obj = json.dumps(get_dictvalue(key[obj_propname]))
 
             return prop_obj
 
@@ -650,7 +667,7 @@ def auto_get_props(
                     auto_get_props(prop_obj)
                     if_wrapper = v.get("IBOX_IF")
                     if if_wrapper:
-                        prop_obj = _iboxif(if_wrapper, obj_propname, prop_obj)
+                        prop_obj = iboxif(if_wrapper, obj_propname, prop_obj)
                     prop_list.append(prop_obj)
             else:
                 for o, v in key[obj_propname].items():
@@ -673,9 +690,10 @@ def auto_get_props(
                     except Exception:
                         prop_list.append(prop_obj)
                     else:
-                        prop_list.append(_iboxif(if_wrapper, mapname, prop_obj))
+                        prop_list.append(iboxif(if_wrapper, mapname, prop_obj))
 
-            return prop_list
+            if prop_list or ibox_sub_obj:
+                return prop_list
 
         # Pure dict as KSM Key KeyPolicy
         elif (
@@ -689,6 +707,8 @@ def auto_get_props(
             return get_dictvalue(key[obj_propname])
 
     def _populate(obj, key=None, mapname=None, rootdict=None):
+        global IBOX_RESNAME, IBOX_CURNAME
+
         if not mapname:
             mapname = obj.title
         if rootdict:
@@ -756,8 +776,8 @@ def auto_get_props(
                 _try_PCO_in_obj(output)
 
         def _process_ibox_auto_pco_key(propname):
-            ibox_auto_po = f"{propname}.IBOX_AUTO_PO"
             ibox_auto_p = f"{propname}.IBOX_AUTO_P"
+            ibox_auto_po = f"{propname}.IBOX_AUTO_PO"
             ibox_pco = f"{propname}.IBOX_PCO"
 
             # IBOX_AUTO_PO
@@ -771,9 +791,10 @@ def auto_get_props(
                 # If there is a key ending with {propname}.IBOX_PCO process it
                 _try_PCO_in_obj(key[ibox_pco])
 
-        def _proc_custom_obj(name, key_value, mapname):
+        def _proc_custom_obj(base_rootdict, key_value, mapname, propname):
             values = []
-            base_rootdict = getattr(cfg, f"{name}IBOX_CUSTOM_OBJ")
+            if not base_rootdict:
+                base_rootdict = getattr(cfg, f"{mapname}IBOX_CUSTOM_OBJ{propname}")
             if isinstance(key_value, dict):
                 my_iter = iter(key_value.items())
                 is_dict = True
@@ -783,12 +804,17 @@ def auto_get_props(
 
             for n, v in my_iter:
                 rootdict = {"Value": v}
+                obj_title = n if is_dict else v
+                if isinstance(v, dict):
+                    rootdict.update(v.get("Conf", {}))
+                    v = v.get("Value", v)
+                    obj_title = f"{n}Value"
                 rootdict.update(base_rootdict)
-                obj = IBOX_Custom_Obj(n if is_dict else v)
-                auto_get_props(obj, rootdict=rootdict)
+                obj = IBOX_Custom_Obj(obj_title)
+                auto_get_props(obj, rootdict=rootdict, mapname=f"{mapname}{propname}")
                 value = getattr(obj, "Value")
                 if v == "IBOX_IFCONDVALUE":
-                    condname = f"{mapname}{n}"
+                    condname = f"{mapname}{propname}{n}"
                     add_obj(get_condition(condname, "not_equals", "IBOX_IFCONDVALUE"))
                     values.append(If(condname, value, Ref("AWS::NoValue")))
                 else:
@@ -880,19 +906,39 @@ def auto_get_props(
                 continue
 
             # IBOX KEY TO LOOK FOR
+            ibox_auto_p = f"{propname}.IBOX_AUTO_P"
             ibox_auto_po = f"{propname}.IBOX_AUTO_PO"
+            ibox_pco = f"{propname}.IBOX_PCO"
             ibox_code = f"{propname}.IBOX_CODE"
             ibox_code_key = f"{propname}.IBOX_CODE_KEY"
             ibox_custom_obj = f"{propname}.IBOX_CUSTOM_OBJ"
 
+            if not isinstance(obj, (Output, Parameter, Condition)):
+                IBOX_CURNAME = f"{mapname}{propname}"
+
+            # IBOX_PCO for Custom Key ONLY
+            # process ibox_pco for custom key not present in obj props
+            # but only if there is not a relative ibox_auto_p/o or ibox_code key
+            if (
+                ibox_pco in key
+                and propname in key
+                and propname not in props
+                and all(n not in key for n in [ibox_auto_p, ibox_auto_po, ibox_code])
+            ):
+                _try_PCO_in_obj(key[ibox_pco])
+
             # IBOX_CODE
             if ibox_code in key and propname in props:
                 # If there is a key ending with {prop}.IBOX_CODE  eval it and use it as prop value.
                 # First process IBOX_AUTO_PO and IBOX_PCO keys
                 _process_ibox_auto_pco_key(propname)
                 value = eval(key[ibox_code])
-            elif propname in key and propname in props:
-                # there is match between obj prop and a dict key
+            elif (
+                propname in key
+                and propname in props
+                or (propname in key and ibox_custom_obj in key)
+            ):
+                # there is match between obj prop and a dict key or there is a custom obj
                 key_value = key[propname]
 
                 # Process IBOX_AUTO_PO and IBOX_PCO keys
@@ -904,12 +950,17 @@ def auto_get_props(
                 # set value
                 elif isinstance(key_value, (list, dict)) and ibox_custom_obj in key:
                     # to process a list like a custom obj
+                    save_ibox_resname = IBOX_RESNAME
                     value = _proc_custom_obj(
-                        key[ibox_custom_obj], key_value, f"{mapname}{propname}"
+                        key[ibox_custom_obj], key_value, mapname, propname
                     )
+                    # need to save and restore IBOX_RESNAME because during processing _proc_custom_obj it change
+                    IBOX_RESNAME = save_ibox_resname
                 elif isinstance(key_value, dict):
                     # key value is a dict, get populated object
                     value = _get_obj(obj, key, propname, mapname)
+                    if value is None:
+                        continue
                 elif isinstance(key_value, str) and key_value.startswith(
                     IBOX_SPECIAL_KEYS
                 ):
@@ -943,7 +994,7 @@ def auto_get_props(
                 except Exception:
                     pass
                 else:
-                    value = _iboxif(if_wrapper, mapname, value)
+                    value = iboxif(if_wrapper, mapname, value)
 
                 if propname == "Condition" and not isinstance(value, str):
                     # Avoid intercepting a Template Condition
@@ -956,6 +1007,9 @@ def auto_get_props(
             # Finally set obj property
             try:
                 setattr(obj, propname, value)
+            except AttributeError:
+                setattr(cfg, f"{mapname}{propname}", value)
+                pass
             except TypeError:
                 pass
             else:
@@ -970,6 +1024,10 @@ def auto_get_props(
                         del ibox_auto_po_value["Description"]
                     _auto_PO(propname, ibox_auto_po_value, "o", value)
 
+        # need to redefine it here because it's has been changed by nested supprop
+        if not isinstance(obj, (Output, Parameter, Condition)):
+            IBOX_CURNAME = mapname
+
         # title override
         try:
             obj.title = parse_ibox_key(key["IBOX_TITLE"])
